@@ -67,6 +67,7 @@ __all__ = [
 		"make_docs_typing_shield",
 		"make_docs_pre_commit_shield",
 		"make_docs_pre_commit_ci_shield",
+		"make_docs_actions_shield",
 		]
 
 
@@ -101,6 +102,31 @@ def make_docs_docs_check_shield(repo_name: str, username: str) -> str:
 	:alt: Docs Check Status"""
 
 
+def make_docs_actions_shield(
+		repo_name: str,
+		username: str,
+		name: str,
+		alt: str,
+		) -> str:
+	"""
+	Create a shield to indicate the status of the tests on Linux.
+
+	:param repo_name: The name of the repository.
+	:param username: The username of the GitHub account that owns the repository.
+	:param name: The name of the workflow.
+	:param alt: Alternative text for the image when it cannot be shown.
+
+	:return: The shield.
+
+	.. versionadded:: 2020.12.16
+	"""
+
+	return f"""\
+.. actions-shield::
+	:workflow: {name}
+	:alt: {alt}"""
+
+
 def make_docs_actions_linux_shield(
 		repo_name: str,
 		username: str,
@@ -114,13 +140,7 @@ def make_docs_actions_linux_shield(
 	:return: The shield.
 	"""
 
-	return """\
-.. actions-shield::
-	:workflow: Linux
-	:alt: Linux Test Status"""
-
-
-make_docs_actions_linux_shield = make_docs_actions_linux_shield
+	return make_docs_actions_shield(repo_name, username, "Linux", "Linux Test Status")
 
 
 def make_docs_actions_windows_shield(repo_name: str, username: str) -> str:
@@ -133,10 +153,7 @@ def make_docs_actions_windows_shield(repo_name: str, username: str) -> str:
 	:return: The shield.
 	"""
 
-	return """\
-.. actions-shield::
-	:workflow: Windows
-	:alt: Windows Test Status"""
+	return make_docs_actions_shield(repo_name, username, "Windows", "Windows Test Status")
 
 
 def make_docs_actions_macos_shield(repo_name: str, username: str) -> str:
@@ -149,10 +166,7 @@ def make_docs_actions_macos_shield(repo_name: str, username: str) -> str:
 	:return: The shield.
 	"""
 
-	return """\
-.. actions-shield::
-	:workflow: macOS
-	:alt: macOS Test Status"""
+	return make_docs_actions_shield(repo_name, username, "macOS", "macOS Test Status")
 
 
 def make_docs_requires_shield(repo_name: str, username: str) -> str:
